#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get joplin.@joplin[0].image_name 2>/dev/null)
}

do_install_detail() {
  local config=$(uci get joplin.@joplin[0].config_path 2>/dev/null)
  local port=$(uci get joplin.@joplin[0].port 2>/dev/null)
  local IMAGE_NAME=$(uci get joplin.@joplin[0].image_name 2>/dev/null)

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)

  LAN_IP=$(uci get network.lan.ipaddr)
  LAN_IP="${LAN_IP%/*}"

  if [ -z "$config" ]; then
    echo "config path is empty!"
    exit 1
  fi

  [ -z "$port" ] && port=22300
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=florider89/joplin-server:latest

  rm -R /opt/docker2/compose/joplin-app
  mkdir /opt/docker2/compose/joplin-app

  touch /opt/docker2/compose/joplin-app/docker-compose.yml
  cat > /opt/docker2/compose/joplin-app/docker-compose.yml <<EOF
version: '3'
services:
    app:
        environment:
            - APP_BASE_URL=http://${LAN_IP}:22300
            - APP_PORT=22300
            - POSTGRES_PASSWORD=${GEN_PASS}
            - POSTGRES_DATABASE=joplin
            - POSTGRES_USER=joplin 
            - POSTGRES_PORT=5432 
            - POSTGRES_HOST=db
            - DB_CLIENT=pg
        restart: unless-stopped
        image: florider89/joplin-server:latest
        ports:
            - 22300:22300
    db:
        restart: unless-stopped
        image: postgres:13.1
        ports:
            - 5432:5432
        volumes:
            - ./data:/var/lib/postgresql/data
        environment:
            - POSTGRES_PASSWORD=${GEN_PASS}
            - POSTGRES_USER=joplin
            - POSTGRES_DB=joplin
    labels:
      plugsy.name: "Joplin"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/material-outlined/NoteAlt"
      plugsy.link: "http://${LAN_IP}:22300"

EOF

  docker-compose -f /opt/docker2/compose/joplin-app/docker-compose.yml up -d

  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install Joplin"
  echo "      upgrade                Upgrade Joplin"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart Joplin"
  echo "      status                 Joplin status"
  echo "      port                   Joplin port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    echo "Stopping and removing containers..."
    for ID in $CONTAINER_IDS; do
      docker stop $ID
      docker rm $ID
    done
    docker rmi -f $IMAGE_NAME
  ;;
  "start"|"stop"|"restart")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    for ID in $CONTAINER_IDS; do
      docker ${ACTION} ${ID}
    done
  ;;
  "status")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
